# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.metalv1.models.href import Href
from typing import Optional, Set
from typing_extensions import Self

class Project(BaseModel):
    """
    Project
    """ # noqa: E501
    backend_transfer_enabled: Optional[StrictBool] = None
    bgp_config: Optional[Href] = None
    created_at: Optional[datetime] = None
    customdata: Optional[Dict[str, Any]] = None
    devices: Optional[List[Href]] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    invitations: Optional[List[Href]] = None
    max_devices: Optional[Dict[str, Any]] = None
    members: Optional[List[Href]] = None
    memberships: Optional[List[Href]] = None
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=80)]] = Field(default=None, description="The name of the project. Cannot contain characters encoded in greater than 3 bytes such as emojis.")
    network_status: Optional[Dict[str, Any]] = None
    organization: Optional[Href] = None
    payment_method: Optional[Href] = None
    ssh_keys: Optional[List[Href]] = None
    tags: Optional[List[StrictStr]] = None
    type: Optional[StrictStr] = Field(default=None, description="The type of the project. Projects of type `vmce` are part of an in development feature and not available to all customers.")
    updated_at: Optional[datetime] = None
    url: Optional[StrictStr] = None
    volumes: Optional[List[Href]] = None
    __properties: ClassVar[List[str]] = ["backend_transfer_enabled", "bgp_config", "created_at", "customdata", "devices", "href", "id", "invitations", "max_devices", "members", "memberships", "name", "network_status", "organization", "payment_method", "ssh_keys", "tags", "type", "updated_at", "url", "volumes"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['default', 'vmce']):
            raise ValueError("must be one of enum values ('default', 'vmce')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Project from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of bgp_config
        if self.bgp_config:
            _dict['bgp_config'] = self.bgp_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in devices (list)
        _items = []
        if self.devices:
            for _item in self.devices:
                if _item:
                    _items.append(_item.to_dict())
            _dict['devices'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in invitations (list)
        _items = []
        if self.invitations:
            for _item in self.invitations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['invitations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item in self.members:
                if _item:
                    _items.append(_item.to_dict())
            _dict['members'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in memberships (list)
        _items = []
        if self.memberships:
            for _item in self.memberships:
                if _item:
                    _items.append(_item.to_dict())
            _dict['memberships'] = _items
        # override the default output from pydantic by calling `to_dict()` of organization
        if self.organization:
            _dict['organization'] = self.organization.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payment_method
        if self.payment_method:
            _dict['payment_method'] = self.payment_method.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in ssh_keys (list)
        _items = []
        if self.ssh_keys:
            for _item in self.ssh_keys:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ssh_keys'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in volumes (list)
        _items = []
        if self.volumes:
            for _item in self.volumes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['volumes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Project from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "backend_transfer_enabled": obj.get("backend_transfer_enabled"),
            "bgp_config": Href.from_dict(obj["bgp_config"]) if obj.get("bgp_config") is not None else None,
            "created_at": obj.get("created_at"),
            "customdata": obj.get("customdata"),
            "devices": [Href.from_dict(_item) for _item in obj["devices"]] if obj.get("devices") is not None else None,
            "href": obj.get("href"),
            "id": obj.get("id"),
            "invitations": [Href.from_dict(_item) for _item in obj["invitations"]] if obj.get("invitations") is not None else None,
            "max_devices": obj.get("max_devices"),
            "members": [Href.from_dict(_item) for _item in obj["members"]] if obj.get("members") is not None else None,
            "memberships": [Href.from_dict(_item) for _item in obj["memberships"]] if obj.get("memberships") is not None else None,
            "name": obj.get("name"),
            "network_status": obj.get("network_status"),
            "organization": Href.from_dict(obj["organization"]) if obj.get("organization") is not None else None,
            "payment_method": Href.from_dict(obj["payment_method"]) if obj.get("payment_method") is not None else None,
            "ssh_keys": [Href.from_dict(_item) for _item in obj["ssh_keys"]] if obj.get("ssh_keys") is not None else None,
            "tags": obj.get("tags"),
            "type": obj.get("type"),
            "updated_at": obj.get("updated_at"),
            "url": obj.get("url"),
            "volumes": [Href.from_dict(_item) for _item in obj["volumes"]] if obj.get("volumes") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.vrf import Vrf

class TestVrf(unittest.TestCase):
    """Vrf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Vrf:
        """Test Vrf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Vrf`
        """
        model = Vrf()
        if include_optional:
            return Vrf(
                bgp_dynamic_neighbors_bfd_enabled = True,
                bgp_dynamic_neighbors_enabled = True,
                bgp_dynamic_neighbors_export_route_map = True,
                bill = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = equinix.services.metalv1.models.user.User(
                    avatar_thumb_url = '', 
                    avatar_url = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    default_organization_id = '', 
                    default_project_id = '', 
                    email = '', 
                    emails = [
                        equinix.services.metalv1.models.href.Href(
                            href = '', )
                        ], 
                    first_name = '', 
                    fraud_score = '', 
                    full_name = '', 
                    href = '', 
                    id = '', 
                    last_login_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_name = '', 
                    max_organizations = 56, 
                    max_projects = 56, 
                    phone_number = '', 
                    short_id = '', 
                    timezone = '', 
                    two_factor_auth = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                description = '',
                href = '',
                id = '',
                ip_ranges = [
                    ''
                    ],
                local_asn = 65000,
                metro = equinix.services.metalv1.models.metro.Metro(
                    code = '', 
                    country = '', 
                    href = '', 
                    id = '', 
                    name = '', ),
                name = '',
                project = equinix.services.metalv1.models.project.Project(
                    backend_transfer_enabled = True, 
                    bgp_config = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    devices = [
                        equinix.services.metalv1.models.href.Href(
                            href = '', )
                        ], 
                    href = '', 
                    id = '', 
                    invitations = [
                        
                        ], 
                    max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                    members = [
                        
                        ], 
                    memberships = [
                        
                        ], 
                    name = '0', 
                    network_status = equinix.services.metalv1.models.network_status.network_status(), 
                    organization = , 
                    payment_method = , 
                    ssh_keys = [
                        
                        ], 
                    tags = [
                        ''
                        ], 
                    type = 'default', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    volumes = [
                        
                        ], ),
                tags = [
                    ''
                    ],
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                virtual_circuits = [
                    equinix.services.metalv1.models.vrf_virtual_circuit.VrfVirtualCircuit(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_ip = '12.0.0.2', 
                        customer_ipv6 = '2604:1380:4641:a00::6', 
                        description = '', 
                        href = '', 
                        id = '', 
                        md5 = '', 
                        metal_ip = '12.0.0.1', 
                        metal_ipv6 = '2604:1380:4641:a00::6', 
                        name = '', 
                        nni_vlan = 56, 
                        peer_asn = 65000, 
                        port = equinix.services.metalv1.models.interconnection_port.InterconnectionPort(
                            href = '', 
                            id = '', 
                            link_status = '', 
                            name = '', 
                            organization = equinix.services.metalv1.models.href.Href(
                                href = '', ), 
                            role = 'primary', 
                            speed = 56, 
                            status = 'requested', 
                            switch_id = '', ), 
                        project = equinix.services.metalv1.models.project.Project(
                            backend_transfer_enabled = True, 
                            bgp_config = equinix.services.metalv1.models.href.Href(
                                href = '', ), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            customdata = equinix.services.metalv1.models.customdata.customdata(), 
                            devices = [
                                
                                ], 
                            href = '', 
                            id = '', 
                            invitations = [
                                
                                ], 
                            max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                            members = [
                                
                                ], 
                            memberships = [
                                
                                ], 
                            name = '0', 
                            network_status = equinix.services.metalv1.models.network_status.network_status(), 
                            payment_method = , 
                            ssh_keys = [
                                
                                ], 
                            tags = [
                                ''
                                ], 
                            type = 'default', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', 
                            volumes = [
                                
                                ], ), 
                        speed = 56, 
                        status = 'pending', 
                        subnet = '12.0.0.0/30', 
                        subnet_ipv6 = '2604:1380:4641:a00::4/126', 
                        tags = [
                            ''
                            ], 
                        type = 'vrf', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        vrf = equinix.services.metalv1.models.vrf.Vrf(
                            bgp_dynamic_neighbors_bfd_enabled = True, 
                            bgp_dynamic_neighbors_enabled = True, 
                            bgp_dynamic_neighbors_export_route_map = True, 
                            bill = True, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            created_by = equinix.services.metalv1.models.user.User(
                                avatar_thumb_url = '', 
                                avatar_url = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customdata = equinix.services.metalv1.models.customdata.customdata(), 
                                default_organization_id = '', 
                                default_project_id = '', 
                                email = '', 
                                emails = [
                                    
                                    ], 
                                first_name = '', 
                                fraud_score = '', 
                                full_name = '', 
                                href = '', 
                                id = '', 
                                last_login_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                last_name = '', 
                                max_organizations = 56, 
                                max_projects = 56, 
                                phone_number = '', 
                                short_id = '', 
                                timezone = '', 
                                two_factor_auth = '', 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            description = '', 
                            href = '', 
                            id = '', 
                            ip_ranges = [
                                ''
                                ], 
                            local_asn = 65000, 
                            metro = equinix.services.metalv1.models.metro.Metro(
                                code = '', 
                                country = '', 
                                href = '', 
                                id = '', 
                                name = '', ), 
                            name = '', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ]
            )
        else:
            return Vrf(
        )
        """

    def testVrf(self):
        """Test Vrf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.fabricv4.models.fabric_cloud_router_price import FabricCloudRouterPrice
from equinix.services.fabricv4.models.ip_block_price import IpBlockPrice
from equinix.services.fabricv4.models.price_category import PriceCategory
from equinix.services.fabricv4.models.price_charge import PriceCharge
from equinix.services.fabricv4.models.price_term_length import PriceTermLength
from equinix.services.fabricv4.models.product_type import ProductType
from equinix.services.fabricv4.models.simplified_account import SimplifiedAccount
from equinix.services.fabricv4.models.time_service_price import TimeServicePrice
from equinix.services.fabricv4.models.virtual_connection_price import VirtualConnectionPrice
from equinix.services.fabricv4.models.virtual_port_price import VirtualPortPrice
from typing import Optional, Set
from typing_extensions import Self

class Price(BaseModel):
    """
    Price
    """ # noqa: E501
    href: Optional[StrictStr] = Field(default=None, description="An absolute URL that returns specified pricing data")
    type: Optional[ProductType] = None
    code: Optional[StrictStr] = Field(default=None, description="Equinix-assigned product code")
    name: Optional[StrictStr] = Field(default=None, description="Full product name")
    description: Optional[StrictStr] = Field(default=None, description="Product description")
    account: Optional[SimplifiedAccount] = None
    charges: Optional[List[PriceCharge]] = None
    currency: Optional[StrictStr] = Field(default=None, description="Product offering price currency")
    term_length: Optional[PriceTermLength] = Field(default=None, alias="termLength")
    catgory: Optional[PriceCategory] = None
    connection: Optional[VirtualConnectionPrice] = None
    ip_block: Optional[IpBlockPrice] = Field(default=None, alias="ipBlock")
    router: Optional[FabricCloudRouterPrice] = None
    port: Optional[VirtualPortPrice] = None
    time_service: Optional[TimeServicePrice] = Field(default=None, alias="timeService")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["href", "type", "code", "name", "description", "account", "charges", "currency", "termLength", "catgory", "connection", "ipBlock", "router", "port", "timeService"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Price from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of account
        if self.account:
            _dict['account'] = self.account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in charges (list)
        _items = []
        if self.charges:
            for _item in self.charges:
                if _item:
                    _items.append(_item.to_dict())
            _dict['charges'] = _items
        # override the default output from pydantic by calling `to_dict()` of connection
        if self.connection:
            _dict['connection'] = self.connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ip_block
        if self.ip_block:
            _dict['ipBlock'] = self.ip_block.to_dict()
        # override the default output from pydantic by calling `to_dict()` of router
        if self.router:
            _dict['router'] = self.router.to_dict()
        # override the default output from pydantic by calling `to_dict()` of port
        if self.port:
            _dict['port'] = self.port.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_service
        if self.time_service:
            _dict['timeService'] = self.time_service.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Price from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "href": obj.get("href"),
            "type": obj.get("type"),
            "code": obj.get("code"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "account": SimplifiedAccount.from_dict(obj["account"]) if obj.get("account") is not None else None,
            "charges": [PriceCharge.from_dict(_item) for _item in obj["charges"]] if obj.get("charges") is not None else None,
            "currency": obj.get("currency"),
            "termLength": obj.get("termLength"),
            "catgory": obj.get("catgory"),
            "connection": VirtualConnectionPrice.from_dict(obj["connection"]) if obj.get("connection") is not None else None,
            "ipBlock": IpBlockPrice.from_dict(obj["ipBlock"]) if obj.get("ipBlock") is not None else None,
            "router": FabricCloudRouterPrice.from_dict(obj["router"]) if obj.get("router") is not None else None,
            "port": VirtualPortPrice.from_dict(obj["port"]) if obj.get("port") is not None else None,
            "timeService": TimeServicePrice.from_dict(obj["timeService"]) if obj.get("timeService") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.projects_api import ProjectsApi


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_project(self) -> None:
        """Test case for create_project

        Create a project
        """
        pass

    def test_create_project_invitation(self) -> None:
        """Test case for create_project_invitation

        Create an invitation for a project
        """
        pass

    def test_create_transfer_request(self) -> None:
        """Test case for create_transfer_request

        Create a transfer request
        """
        pass

    def test_delete_project(self) -> None:
        """Test case for delete_project

        Delete the project
        """
        pass

    def test_find_ip_reservation_customdata(self) -> None:
        """Test case for find_ip_reservation_customdata

        Retrieve the custom metadata of an IP Reservation
        """
        pass

    def test_find_project_by_id(self) -> None:
        """Test case for find_project_by_id

        Retrieve a project
        """
        pass

    def test_find_project_customdata(self) -> None:
        """Test case for find_project_customdata

        Retrieve the custom metadata of a project
        """
        pass

    def test_find_project_invitations(self) -> None:
        """Test case for find_project_invitations

        Retrieve project invitations
        """
        pass

    def test_find_project_memberships(self) -> None:
        """Test case for find_project_memberships

        Retrieve project memberships
        """
        pass

    def test_find_projects(self) -> None:
        """Test case for find_projects

        Retrieve all projects
        """
        pass

    def test_find_projects_all_pages(self):
        """Test case for find_projects_all_pages

        Retrieve all projects  # noqa: E501
        """
        pass

    def test_update_project(self) -> None:
        """Test case for update_project

        Update the project
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.connection_search_response import ConnectionSearchResponse

class TestConnectionSearchResponse(unittest.TestCase):
    """ConnectionSearchResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConnectionSearchResponse:
        """Test ConnectionSearchResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConnectionSearchResponse`
        """
        model = ConnectionSearchResponse()
        if include_optional:
            return ConnectionSearchResponse(
                pagination = equinix.services.fabricv4.models.pagination.Pagination(
                    offset = 0, 
                    limit = 0, 
                    total = 0, 
                    next = '', 
                    previous = '', ),
                sort = [
                    equinix.services.fabricv4.models.sort_criteria_response.SortCriteriaResponse(
                        direction = 'DESC', 
                        property = '/changeLog/updatedDateTime', )
                    ],
                data = [
                    equinix.services.fabricv4.models.connection.Connection(
                        href = '', 
                        type = 'EVPL_VC', 
                        uuid = '', 
                        name = '', 
                        description = '', 
                        state = 'ACTIVE', 
                        change = equinix.services.fabricv4.models.change.Change(
                            uuid = '', 
                            type = 'CONNECTION_CREATION', 
                            status = 'APPROVED', 
                            created_date_time = '2020-11-06T07:00Z', 
                            updated_date_time = '2020-11-06T07:00Z', 
                            information = '', 
                            data = equinix.services.fabricv4.models.connection_change_operation.ConnectionChangeOperation(
                                op = 'add', 
                                path = '/ipv6', 
                                value = equinix.services.fabricv4.models.value.value(), ), ), 
                        operation = equinix.services.fabricv4.models.connection_operation.ConnectionOperation(
                            provider_status = 'AVAILABLE', 
                            equinix_status = 'REJECTED_ACK', 
                            operational_status = 'UP', 
                            errors = [
                                equinix.services.fabricv4.models.error.Error(
                                    error_code = 'EQ-0480728', 
                                    error_message = '', 
                                    correlation_id = '', 
                                    details = '', 
                                    help = '', 
                                    additional_info = [
                                        equinix.services.fabricv4.models.price_error_additional_info.PriceError_additionalInfo(
                                            property = '', 
                                            reason = '', )
                                        ], )
                                ], 
                            op_status_changed_at = '2020-11-06T07:00Z', ), 
                        order = equinix.services.fabricv4.models.order.Order(
                            purchase_order_number = '', 
                            customer_reference_number = '', 
                            billing_tier = '', 
                            order_id = '', 
                            order_number = '', ), 
                        notifications = [
                            equinix.services.fabricv4.models.simplified_notification.SimplifiedNotification(
                                type = 'BANDWIDTH_ALERT', 
                                send_interval = '', 
                                emails = [
                                    ''
                                    ], 
                                registered_users = [
                                    ''
                                    ], )
                            ], 
                        account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                            account_number = 56, 
                            account_name = '', 
                            org_id = 56, 
                            organization_name = '', 
                            global_org_id = '', 
                            global_organization_name = '', 
                            ucm_id = '', 
                            global_cust_id = '', 
                            reseller_account_number = 56, 
                            reseller_account_name = '', 
                            reseller_ucm_id = '', 
                            reseller_org_id = 56, ), 
                        change_log = equinix.services.fabricv4.models.changelog.Changelog(
                            created_by = 'johnsmith', 
                            created_by_full_name = 'John Smith', 
                            created_by_email = 'john.smith@example.com', 
                            created_date_time = '2020-11-06T07:00Z', 
                            updated_by = 'johnsmith', 
                            updated_by_full_name = 'John Smith', 
                            updated_by_email = 'john.smith@example.com', 
                            updated_date_time = '2020-11-06T07:00Z', 
                            deleted_by = 'johnsmith', 
                            deleted_by_full_name = 'John Smith', 
                            deleted_by_email = 'john.smith@example.com', 
                            deleted_date_time = '2020-11-06T07:00Z', ), 
                        bandwidth = 0, 
                        geo_scope = 'CANADA', 
                        redundancy = equinix.services.fabricv4.models.connection_redundancy.ConnectionRedundancy(
                            group = '', 
                            priority = 'PRIMARY', ), 
                        is_remote = True, 
                        direction = 'INTERNAL', 
                        a_side = equinix.services.fabricv4.models.connection_side.ConnectionSide(
                            service_token = equinix.services.fabricv4.models.service_token.ServiceToken(
                                href = '', 
                                expiry = 56, 
                                uuid = '', 
                                issuer_side = '', 
                                name = '', 
                                description = '', 
                                expiration_date_time = '2020-11-06T07:00Z', 
                                connection = equinix.services.fabricv4.models.service_token_connection.ServiceTokenConnection(
                                    type = 'EVPL_VC', 
                                    href = '', 
                                    uuid = '', 
                                    allow_remote_connection = True, 
                                    allow_custom_bandwidth = True, 
                                    bandwidth_limit = 0, 
                                    supported_bandwidths = [
                                        56
                                        ], 
                                    z_side = equinix.services.fabricv4.models.service_token_side.ServiceTokenSide(
                                        access_point_selectors = [
                                            equinix.services.fabricv4.models.access_point_selector.AccessPointSelector(
                                                hide_asset_info = True, 
                                                port = equinix.services.fabricv4.models.simplified_metadata_entity.SimplifiedMetadataEntity(
                                                    href = '', 
                                                    uuid = '', 
                                                    cvp_id = 56, 
                                                    bandwidth = 1.337, 
                                                    port_name = '', 
                                                    encapsulation_protocol_type = '', 
                                                    account_name = '', 
                                                    location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                                                        metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                                                        region = 'AMER, APAC, EMEA', 
                                                        metro_name = 'Amsterdam', 
                                                        metro_code = 'AM', 
                                                        ibx = 'AM1', ), ), 
                                                link_protocol = equinix.services.fabricv4.models.simplified_link_protocol.SimplifiedLinkProtocol(
                                                    vlan_tag = 2, 
                                                    vlan_s_tag = 2, 
                                                    vlan_c_tag = 2, ), 
                                                virtual_device = equinix.services.fabricv4.models.simplified_virtual_device.SimplifiedVirtualDevice(
                                                    href = '', 
                                                    uuid = '', 
                                                    name = '', 
                                                    cluster = '', ), 
                                                interface = equinix.services.fabricv4.models.virtual_device_interface.VirtualDeviceInterface(
                                                    id = 56, 
                                                    uuid = '', ), 
                                                network = equinix.services.fabricv4.models.simplified_token_network.SimplifiedTokenNetwork(
                                                    href = '', 
                                                    uuid = '', 
                                                    name = '', 
                                                    scope = 'LOCAL', ), )
                                            ], ), ), 
                                changelog = equinix.services.fabricv4.models.changelog.Changelog(
                                    created_by = 'johnsmith', 
                                    created_by_full_name = 'John Smith', 
                                    created_by_email = 'john.smith@example.com', 
                                    created_date_time = '2020-11-06T07:00Z', 
                                    updated_by = 'johnsmith', 
                                    updated_by_full_name = 'John Smith', 
                                    updated_by_email = 'john.smith@example.com', 
                                    updated_date_time = '2020-11-06T07:00Z', 
                                    deleted_by = 'johnsmith', 
                                    deleted_by_full_name = 'John Smith', 
                                    deleted_by_email = 'john.smith@example.com', 
                                    deleted_date_time = '2020-11-06T07:00Z', ), 
                                project = equinix.services.fabricv4.models.project.Project(
                                    project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), ), 
                            access_point = equinix.services.fabricv4.models.access_point.AccessPoint(
                                profile = equinix.services.fabricv4.models.simplified_service_profile.SimplifiedServiceProfile(
                                    href = '', 
                                    name = 'Sample Service Profile', 
                                    uuid = '', 
                                    description = 'offering connectivity to my-network', 
                                    tags = [
                                        ''
                                        ], 
                                    visibility = 'PRIVATE', 
                                    allowed_emails = [
                                        ''
                                        ], 
                                    access_point_type_configs = [
                                        equinix.services.fabricv4.models.service_profile_access_point_type.ServiceProfileAccessPointType()
                                        ], 
                                    custom_fields = [
                                        equinix.services.fabricv4.models.custom_field.CustomField(
                                            label = 'Account Number', 
                                            description = 'Provide a valid account number', 
                                            required = True, 
                                            data_type = 'STRING', 
                                            options = [
                                                ''
                                                ], 
                                            capture_in_email = True, )
                                        ], 
                                    marketing_info = equinix.services.fabricv4.models.marketing_info.MarketingInfo(
                                        logo = '', 
                                        promotion = True, 
                                        process_steps = [
                                            equinix.services.fabricv4.models.process_step.ProcessStep(
                                                title = '', 
                                                sub_title = '', 
                                                description = '', )
                                            ], ), 
                                    ports = [
                                        equinix.services.fabricv4.models.service_profile_access_point_colo.ServiceProfileAccessPointCOLO(
                                            type = 'XF_PORT', 
                                            uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                                            seller_region = '', 
                                            seller_region_description = '', 
                                            cross_connect_id = '', )
                                        ], 
                                    virtual_devices = [
                                        equinix.services.fabricv4.models.service_profile_access_point_vd.ServiceProfileAccessPointVD(
                                            type = 'VD', 
                                            uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                                            interface_uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', )
                                        ], 
                                    metros = [
                                        equinix.services.fabricv4.models.service_metro.ServiceMetro(
                                            code = '', 
                                            name = '', 
                                            vc_bandwidth_max = 56, 
                                            ibxs = [
                                                ''
                                                ], 
                                            in_trail = True, 
                                            display_name = '', 
                                            seller_regions = {
                                                'key' : ''
                                                }, )
                                        ], 
                                    self_profile = True, 
                                    project_id = '', ), 
                                router = equinix.services.fabricv4.models.cloud_router.CloudRouter(
                                    href = 'https://api.equinix.com/fabric/v4/routers/3c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                                    uuid = 'c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                                    name = 'test-fg-1', 
                                    equinix_asn = 30000, 
                                    connections_count = 0, 
                                    marketplace_subscription = equinix.services.fabricv4.models.marketplace_subscription.marketplaceSubscription(
                                        href = 'https://api.equinix.com/fabric/v4/marketplaceSubscriptions/20d32a80-0d61-4333-bc03-707b591ae2f5', 
                                        uuid = '20d32a80-0d61-4333-bc03-707b591ae2f5', ), ), 
                                seller_region = '', 
                                peering_type = 'PRIVATE', 
                                authentication_key = '', 
                                provider_connection_id = '', 
                                virtual_network = equinix.services.fabricv4.models.virtual_network.VirtualNetwork(
                                    href = '', 
                                    uuid = '', ), 
                                interconnection = equinix.services.fabricv4.models.metal_interconnection.MetalInterconnection(
                                    uuid = '', ), 
                                vpic_interface = equinix.services.fabricv4.models.vpic_interface.VpicInterface(
                                    href = '', 
                                    uuid = '', ), ), 
                            internet_access = equinix.services.fabricv4.models.internet_access.InternetAccess(
                                uuid = '', ), 
                            company_profile = equinix.services.fabricv4.models.connection_company_profile.ConnectionCompanyProfile(
                                id = 1, 
                                name = 'Company-1', 
                                global_org_id = '', ), 
                            invitation = equinix.services.fabricv4.models.connection_invitation.ConnectionInvitation(
                                email = 'test@equinix.com', 
                                message = 'Hello, Please accept my invitation', 
                                ctr_draft_order_id = '', ), ), 
                        z_side = equinix.services.fabricv4.models.connection_side.ConnectionSide(), 
                        marketplace_subscription = equinix.services.fabricv4.models.marketplace_subscription.marketplaceSubscription(
                            href = 'https://api.equinix.com/fabric/v4/marketplaceSubscriptions/20d32a80-0d61-4333-bc03-707b591ae2f5', 
                            uuid = '20d32a80-0d61-4333-bc03-707b591ae2f5', ), 
                        additional_info = [
                            equinix.services.fabricv4.models.connection_side_additional_info.ConnectionSideAdditionalInfo(
                                key = '', 
                                value = '', )
                            ], 
                        project = equinix.services.fabricv4.models.project.Project(
                            project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), )
                    ]
            )
        else:
            return ConnectionSearchResponse(
        )
        """

    def testConnectionSearchResponse(self):
        """Test ConnectionSearchResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Component(BaseModel):
    """
    Component
    """ # noqa: E501
    checksum: Optional[StrictStr] = Field(default=None, description="File checksum")
    component: Optional[StrictStr] = Field(default=None, description="Component type")
    created_at: Optional[datetime] = Field(default=None, description="Datetime when the block was created.")
    filename: Optional[StrictStr] = Field(default=None, description="name of the file")
    href: Optional[StrictStr] = None
    model: Optional[List[StrictStr]] = Field(default=None, description="List of models where this component version can be applied")
    repository_url: Optional[StrictStr] = Field(default=None, description="Location of the file in the repository")
    updated_at: Optional[datetime] = Field(default=None, description="Datetime when the block was updated.")
    upstream_url: Optional[StrictStr] = Field(default=None, description="Location of the file")
    uuid: Optional[StrictStr] = Field(default=None, description="Component UUID")
    vendor: Optional[StrictStr] = Field(default=None, description="Component vendor")
    version: Optional[StrictStr] = Field(default=None, description="Version of the component")
    __properties: ClassVar[List[str]] = ["checksum", "component", "created_at", "filename", "href", "model", "repository_url", "updated_at", "upstream_url", "uuid", "vendor", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Component from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "checksum",
            "component",
            "created_at",
            "filename",
            "model",
            "repository_url",
            "updated_at",
            "upstream_url",
            "uuid",
            "vendor",
            "version",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Component from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "checksum": obj.get("checksum"),
            "component": obj.get("component"),
            "created_at": obj.get("created_at"),
            "filename": obj.get("filename"),
            "href": obj.get("href"),
            "model": obj.get("model"),
            "repository_url": obj.get("repository_url"),
            "updated_at": obj.get("updated_at"),
            "upstream_url": obj.get("upstream_url"),
            "uuid": obj.get("uuid"),
            "vendor": obj.get("vendor"),
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.metadata_network import MetadataNetwork
from typing import Optional, Set
from typing_extensions import Self

class Metadata(BaseModel):
    """
    Metadata
    """ # noqa: E501
    var_class: Optional[StrictStr] = Field(default=None, alias="class")
    customdata: Optional[Dict[str, Any]] = None
    facility: Optional[StrictStr] = Field(default=None, description="The facility code of the instance")
    hostname: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    iqn: Optional[StrictStr] = None
    metro: Optional[StrictStr] = Field(default=None, description="The metro code of the instance")
    network: Optional[MetadataNetwork] = None
    operating_system: Optional[Dict[str, Any]] = None
    plan: Optional[StrictStr] = Field(default=None, description="The plan slug of the instance")
    private_subnets: Optional[List[StrictStr]] = Field(default=None, description="An array of the private subnets")
    reserved: Optional[StrictBool] = None
    specs: Optional[Dict[str, Any]] = Field(default=None, description="The specs of the plan version of the instance")
    ssh_keys: Optional[List[StrictStr]] = None
    state: Optional[StrictStr] = Field(default=None, description="The current state the instance is in.  * When an instance is initially created it will be in the `queued` state until it is picked up by the provisioner. * Once provisioning has begun on the instance it's state will move to `provisioning`. * When an instance is deleted, it will move to `deprovisioning` state until the deprovision is completed and the instance state moves to `deleted`. * If an instance fails to provision or deprovision it will move to `failed` state. * Once an instance has completed provisioning it will move to `active` state. * If an instance is currently powering off or powering on it will move to `powering_off` or `powering_on` states respectively.  * When the instance is powered off completely it will move to the `inactive` state. * When an instance is powered on completely it will move to the `active` state. * Using the reinstall action to install a new OS on the instance will cause the instance state to change to `reinstalling`. * When the reinstall action is complete the instance will move to `active` state.")
    switch_short_id: Optional[StrictStr] = None
    tags: Optional[List[StrictStr]] = None
    volumes: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = ["class", "customdata", "facility", "hostname", "href", "id", "iqn", "metro", "network", "operating_system", "plan", "private_subnets", "reserved", "specs", "ssh_keys", "state", "switch_short_id", "tags", "volumes"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['queued', 'provisioning', 'deprovisioning', 'reinstalling', 'active', 'inactive', 'failed', 'powering_on', 'powering_off', 'deleted']):
            raise ValueError("must be one of enum values ('queued', 'provisioning', 'deprovisioning', 'reinstalling', 'active', 'inactive', 'failed', 'powering_on', 'powering_off', 'deleted')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Metadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of network
        if self.network:
            _dict['network'] = self.network.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Metadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "class": obj.get("class"),
            "customdata": obj.get("customdata"),
            "facility": obj.get("facility"),
            "hostname": obj.get("hostname"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "iqn": obj.get("iqn"),
            "metro": obj.get("metro"),
            "network": MetadataNetwork.from_dict(obj["network"]) if obj.get("network") is not None else None,
            "operating_system": obj.get("operating_system"),
            "plan": obj.get("plan"),
            "private_subnets": obj.get("private_subnets"),
            "reserved": obj.get("reserved"),
            "specs": obj.get("specs"),
            "ssh_keys": obj.get("ssh_keys"),
            "state": obj.get("state"),
            "switch_short_id": obj.get("switch_short_id"),
            "tags": obj.get("tags"),
            "volumes": obj.get("volumes")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.create_self_service_reservation_request import CreateSelfServiceReservationRequest

class TestCreateSelfServiceReservationRequest(unittest.TestCase):
    """CreateSelfServiceReservationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateSelfServiceReservationRequest:
        """Test CreateSelfServiceReservationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateSelfServiceReservationRequest`
        """
        model = CreateSelfServiceReservationRequest()
        if include_optional:
            return CreateSelfServiceReservationRequest(
                href = '',
                item = [
                    equinix.services.metalv1.models.self_service_reservation_item_request.SelfServiceReservationItemRequest(
                        href = '', 
                        metro_id = '', 
                        plan_id = '', 
                        quantity = 56, 
                        term = '', )
                    ],
                notes = '',
                period = equinix.services.metalv1.models.create_self_service_reservation_request_period.CreateSelfServiceReservationRequest_period(
                    count = 12, 
                    href = '', 
                    unit = 'monthly', ),
                start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return CreateSelfServiceReservationRequest(
        )
        """

    def testCreateSelfServiceReservationRequest(self):
        """Test CreateSelfServiceReservationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SpotMarketRequestCreateInputInstanceParameters(BaseModel):
    """
    SpotMarketRequestCreateInputInstanceParameters
    """ # noqa: E501
    always_pxe: Optional[StrictBool] = None
    billing_cycle: Optional[StrictStr] = None
    customdata: Optional[Dict[str, Any]] = None
    description: Optional[StrictStr] = None
    features: Optional[List[StrictStr]] = None
    hostname: Optional[StrictStr] = None
    hostnames: Optional[List[StrictStr]] = None
    href: Optional[StrictStr] = None
    locked: Optional[StrictBool] = Field(default=None, description="Whether the device should be locked, preventing accidental deletion.")
    no_ssh_keys: Optional[StrictBool] = None
    operating_system: Optional[StrictStr] = None
    plan: Optional[StrictStr] = None
    private_ipv4_subnet_size: Optional[StrictInt] = None
    project_ssh_keys: Optional[List[StrictStr]] = None
    public_ipv4_subnet_size: Optional[StrictInt] = None
    tags: Optional[List[StrictStr]] = None
    termination_time: Optional[datetime] = None
    user_ssh_keys: Optional[List[StrictStr]] = Field(default=None, description="The UUIDs of users whose SSH keys should be included on the provisioned device.")
    userdata: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["always_pxe", "billing_cycle", "customdata", "description", "features", "hostname", "hostnames", "href", "locked", "no_ssh_keys", "operating_system", "plan", "private_ipv4_subnet_size", "project_ssh_keys", "public_ipv4_subnet_size", "tags", "termination_time", "user_ssh_keys", "userdata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SpotMarketRequestCreateInputInstanceParameters from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SpotMarketRequestCreateInputInstanceParameters from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "always_pxe": obj.get("always_pxe"),
            "billing_cycle": obj.get("billing_cycle"),
            "customdata": obj.get("customdata"),
            "description": obj.get("description"),
            "features": obj.get("features"),
            "hostname": obj.get("hostname"),
            "hostnames": obj.get("hostnames"),
            "href": obj.get("href"),
            "locked": obj.get("locked"),
            "no_ssh_keys": obj.get("no_ssh_keys"),
            "operating_system": obj.get("operating_system"),
            "plan": obj.get("plan"),
            "private_ipv4_subnet_size": obj.get("private_ipv4_subnet_size"),
            "project_ssh_keys": obj.get("project_ssh_keys"),
            "public_ipv4_subnet_size": obj.get("public_ipv4_subnet_size"),
            "tags": obj.get("tags"),
            "termination_time": obj.get("termination_time"),
            "user_ssh_keys": obj.get("user_ssh_keys"),
            "userdata": obj.get("userdata")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from equinix.services.metalv1.models.facility_input_facility import FacilityInputFacility
from equinix.services.metalv1.models.ip_address import IPAddress
from equinix.services.metalv1.models.ssh_key_input import SSHKeyInput
from equinix.services.metalv1.models.storage import Storage
from typing import Optional, Set
from typing_extensions import Self

class InstancesBatchCreateInputBatchesInner(BaseModel):
    """
    InstancesBatchCreateInputBatchesInner
    """ # noqa: E501
    hostnames: Optional[List[StrictStr]] = None
    quantity: Optional[StrictInt] = Field(default=None, description="The number of devices to create in this batch. The hostname may contain an `{{index}}` placeholder, which will be replaced with the index of the device in the batch. For example, if the hostname is `device-{{index}}`, the first device in the batch will have the hostname `device-01`, the second device will have the hostname `device-02`, and so on.")
    href: Optional[StrictStr] = None
    metro: StrictStr = Field(description="Metro code or ID of where the device should be provisioned in, or it can be instructed to create the device in the best available metro with `{ \"metro\": \"any\" }`. The special metro value of any means anywhere, any metro. When any is chosen in the request, the metro location is picked per our scheduling algorithms that favor the following factors: hardware reservation location (if requesting reserved hardware), ip reservations, spot instances, etc. The any keyword *does not* optimize for cost, this means that usage costs (instance, transfer, other features dependent on location) will vary. Please check metro value in response to see where the device was created. Either metro or facility must be provided.")
    always_pxe: Optional[StrictBool] = Field(default=None, description="When true, devices with a `custom_ipxe` OS will always boot to iPXE. The default setting of false ensures that iPXE will be used on only the first boot.")
    billing_cycle: Optional[StrictStr] = Field(default=None, description="The billing cycle of the device.")
    customdata: Optional[Dict[str, Any]] = Field(default=None, description="Customdata is an arbitrary JSON value that can be accessed via the metadata service.")
    description: Optional[StrictStr] = Field(default=None, description="Any description of the device or how it will be used. This may be used to inform other API consumers with project access.")
    features: Optional[List[StrictStr]] = Field(default=None, description="The features attribute allows you to optionally specify what features your server should have.  In the API shorthand syntax, all features listed are `required`:  ``` { \"features\": [\"tpm\"] } ```  Alternatively, if you do not require a certain feature, but would prefer to be assigned a server with that feature if there are any available, you may specify that feature with a `preferred` value. The request will not fail if we have no servers with that feature in our inventory. The API offers an alternative syntax for mixing preferred and required features:  ``` { \"features\": { \"tpm\": \"required\", \"raid\": \"preferred\" } } ```  The request will only fail if there are no available servers matching the required `tpm` criteria.")
    hardware_reservation_id: Optional[StrictStr] = Field(default=None, description="The Hardware Reservation UUID to provision. Alternatively, `next-available` can be specified to select from any of the available hardware reservations. An error will be returned if the requested reservation option is not available.  See [Reserved Hardware](https://deploy.equinix.com/developers/docs/metal/deploy/reserved/) for more details.")
    hostname: Optional[StrictStr] = Field(default=None, description="The hostname to use within the operating system. The same hostname may be used on multiple devices within a project.")
    ip_addresses: Optional[List[IPAddress]] = Field(default=None, description="The `ip_addresses attribute will allow you to specify the addresses you want created with your device.  The default value configures public IPv4, public IPv6, and private IPv4.  Private IPv4 address is required. When specifying `ip_addresses`, one of the array items must enable private IPv4.  Some operating systems require public IPv4 address. In those cases you will receive an error message if public IPv4 is not enabled.  For example, to only configure your server with a private IPv4 address, you can send `{ \"ip_addresses\": [{ \"address_family\": 4, \"public\": false }] }`.  It is possible to request a subnet size larger than a `/30` by assigning addresses using the UUID(s) of ip_reservations in your project.  For example, `{ \"ip_addresses\": [..., {\"address_family\": 4, \"public\": true, \"ip_reservations\": [\"uuid1\", \"uuid2\"]}] }`  To access a server without public IPs, you can use our Out-of-Band console access (SOS) or proxy through another server in the project with public IPs enabled.")
    ipxe_script_url: Optional[StrictStr] = Field(default=None, description="When set, the device will chainload an iPXE Script at boot fetched from the supplied URL.  See [Custom iPXE](https://deploy.equinix.com/developers/docs/metal/operating-systems/custom-ipxe/) for more details.")
    locked: Optional[StrictBool] = Field(default=False, description="Whether the device should be locked, preventing accidental deletion.")
    network_frozen: Optional[StrictBool] = Field(default=None, description="If true, this instance can not be converted to a different network type.")
    no_ssh_keys: Optional[StrictBool] = Field(default=False, description="Overrides default behaviour of attaching all of the organization members ssh keys and project ssh keys to device if no specific keys specified")
    operating_system: StrictStr = Field(description="The slug of the operating system to provision. Check the Equinix Metal operating system documentation for rules that may be imposed per operating system, including restrictions on IP address options and device plans.")
    plan: StrictStr = Field(description="The slug of the device plan to provision.")
    private_ipv4_subnet_size: Optional[StrictInt] = Field(default=None, description="Deprecated. Use ip_addresses. Subnet range for addresses allocated to this device.")
    project_ssh_keys: Optional[List[StrictStr]] = Field(default=None, description="A list of UUIDs identifying the device parent project that should be authorized to access this device (typically via /root/.ssh/authorized_keys). These keys will also appear in the device metadata.  If no SSH keys are specified (`user_ssh_keys`, `project_ssh_keys`, and `ssh_keys` are all empty lists or omitted), all parent project keys, parent project members keys and organization members keys will be included. This behaviour can be changed with 'no_ssh_keys' option to omit any SSH key being added. ")
    public_ipv4_subnet_size: Optional[StrictInt] = Field(default=None, description="Deprecated. Use ip_addresses. Subnet range for addresses allocated to this device. Your project must have addresses available for a non-default request.")
    spot_instance: Optional[StrictBool] = Field(default=None, description="Create a spot instance. Spot instances are created with a maximum bid price. If the bid price is not met, the spot instance will be terminated as indicated by the `termination_time` field.")
    spot_price_max: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The maximum amount to bid for a spot instance.")
    ssh_keys: Optional[List[SSHKeyInput]] = Field(default=None, description="A list of new or existing project ssh_keys that should be authorized to access this device (typically via /root/.ssh/authorized_keys). These keys will also appear in the device metadata.  These keys are added in addition to any keys defined by   `project_ssh_keys` and `user_ssh_keys`. ")
    storage: Optional[Storage] = None
    tags: Optional[List[StrictStr]] = None
    termination_time: Optional[datetime] = Field(default=None, description="When the device will be terminated. If you don't supply timezone info, the timestamp is assumed to be in UTC.  This is commonly set in advance for ephemeral spot market instances but this field may also be set with on-demand and reservation instances to automatically delete the resource at a given time. The termination time can also be used to release a hardware reservation instance at a given time, keeping the reservation open for other uses.  On a spot market device, the termination time will be set automatically when outbid. ")
    user_ssh_keys: Optional[List[StrictStr]] = Field(default=None, description="A list of UUIDs identifying the users that should be authorized to access this device (typically via /root/.ssh/authorized_keys).  These keys will also appear in the device metadata.  The users must be members of the project or organization.  If no SSH keys are specified (`user_ssh_keys`, `project_ssh_keys`, and `ssh_keys` are all empty lists or omitted), all parent project keys, parent project members keys and organization members keys will be included. This behaviour can be changed with 'no_ssh_keys' option to omit any SSH key being added. ")
    userdata: Optional[StrictStr] = Field(default=None, description="The userdata presented in the metadata service for this device.  Userdata is fetched and interpreted by the operating system installed on the device. Acceptable formats are determined by the operating system, with the exception of a special iPXE enabling syntax which is handled before the operating system starts.  See [Server User Data](https://deploy.equinix.com/developers/docs/metal/server-metadata/user-data/) and [Provisioning with Custom iPXE](https://deploy.equinix.com/developers/docs/metal/operating-systems/custom-ipxe/#provisioning-with-custom-ipxe) for more details.")
    facility: FacilityInputFacility
    __properties: ClassVar[List[str]] = ["hostnames", "quantity", "href", "metro", "always_pxe", "billing_cycle", "customdata", "description", "features", "hardware_reservation_id", "hostname", "ip_addresses", "ipxe_script_url", "locked", "network_frozen", "no_ssh_keys", "operating_system", "plan", "private_ipv4_subnet_size", "project_ssh_keys", "public_ipv4_subnet_size", "spot_instance", "spot_price_max", "ssh_keys", "storage", "tags", "termination_time", "user_ssh_keys", "userdata", "facility"]

    @field_validator('billing_cycle')
    def billing_cycle_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['hourly', 'daily', 'monthly', 'yearly']):
            raise ValueError("must be one of enum values ('hourly', 'daily', 'monthly', 'yearly')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InstancesBatchCreateInputBatchesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in ip_addresses (list)
        _items = []
        if self.ip_addresses:
            for _item in self.ip_addresses:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ip_addresses'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ssh_keys (list)
        _items = []
        if self.ssh_keys:
            for _item in self.ssh_keys:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ssh_keys'] = _items
        # override the default output from pydantic by calling `to_dict()` of storage
        if self.storage:
            _dict['storage'] = self.storage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of facility
        if self.facility:
            _dict['facility'] = self.facility.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InstancesBatchCreateInputBatchesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "hostnames": obj.get("hostnames"),
            "quantity": obj.get("quantity"),
            "href": obj.get("href"),
            "metro": obj.get("metro"),
            "always_pxe": obj.get("always_pxe"),
            "billing_cycle": obj.get("billing_cycle"),
            "customdata": obj.get("customdata"),
            "description": obj.get("description"),
            "features": obj.get("features"),
            "hardware_reservation_id": obj.get("hardware_reservation_id"),
            "hostname": obj.get("hostname"),
            "ip_addresses": [IPAddress.from_dict(_item) for _item in obj["ip_addresses"]] if obj.get("ip_addresses") is not None else None,
            "ipxe_script_url": obj.get("ipxe_script_url"),
            "locked": obj.get("locked") if obj.get("locked") is not None else False,
            "network_frozen": obj.get("network_frozen"),
            "no_ssh_keys": obj.get("no_ssh_keys") if obj.get("no_ssh_keys") is not None else False,
            "operating_system": obj.get("operating_system"),
            "plan": obj.get("plan"),
            "private_ipv4_subnet_size": obj.get("private_ipv4_subnet_size"),
            "project_ssh_keys": obj.get("project_ssh_keys"),
            "public_ipv4_subnet_size": obj.get("public_ipv4_subnet_size"),
            "spot_instance": obj.get("spot_instance"),
            "spot_price_max": obj.get("spot_price_max"),
            "ssh_keys": [SSHKeyInput.from_dict(_item) for _item in obj["ssh_keys"]] if obj.get("ssh_keys") is not None else None,
            "storage": Storage.from_dict(obj["storage"]) if obj.get("storage") is not None else None,
            "tags": obj.get("tags"),
            "termination_time": obj.get("termination_time"),
            "user_ssh_keys": obj.get("user_ssh_keys"),
            "userdata": obj.get("userdata"),
            "facility": FacilityInputFacility.from_dict(obj["facility"]) if obj.get("facility") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class VrfMetalGatewayCreateInput(BaseModel):
    """
    VrfMetalGatewayCreateInput
    """ # noqa: E501
    href: Optional[StrictStr] = None
    ip_reservation_id: StrictStr = Field(description="The UUID an a VRF IP Reservation that belongs to the same project as the one in which the Metal Gateway is to be created. Additionally, the VRF IP Reservation and the Virtual Network must reside in the same Metro.")
    virtual_network_id: StrictStr = Field(description="The UUID of a Metro Virtual Network that belongs to the same project as the one in which the Metal Gateway is to be created. Additionally, the Virtual Network and the VRF IP Reservation must reside in the same metro. In the case of the IP reservation being an IPv6 based VRF IP Reservation, the Virtual Network must not already have an associated IPv6 based VRF IP Reservation. There can be exactly one IPv6 based VRF IP Reservation associated to a Virtual Network.")
    __properties: ClassVar[List[str]] = ["href", "ip_reservation_id", "virtual_network_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VrfMetalGatewayCreateInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VrfMetalGatewayCreateInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "href": obj.get("href"),
            "ip_reservation_id": obj.get("ip_reservation_id"),
            "virtual_network_id": obj.get("virtual_network_id")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_prices_report import SpotPricesReport

class TestSpotPricesReport(unittest.TestCase):
    """SpotPricesReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotPricesReport:
        """Test SpotPricesReport
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotPricesReport`
        """
        model = SpotPricesReport()
        if include_optional:
            return SpotPricesReport(
                ams1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                atl1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                dfw1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                ewr1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                fra1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                href = '',
                iad1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                lax1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                nrt1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                ord1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                sea1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                sin1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                sjc1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                syd1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                yyz1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', )
            )
        else:
            return SpotPricesReport(
        )
        """

    def testSpotPricesReport(self):
        """Test SpotPricesReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.payment_method_list import PaymentMethodList

class TestPaymentMethodList(unittest.TestCase):
    """PaymentMethodList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodList:
        """Test PaymentMethodList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodList`
        """
        model = PaymentMethodList()
        if include_optional:
            return PaymentMethodList(
                href = '',
                payment_methods = [
                    equinix.services.metalv1.models.payment_method.PaymentMethod(
                        billing_address = equinix.services.metalv1.models.payment_method_billing_address.PaymentMethodBillingAddress(
                            country_code_alpha2 = '', 
                            href = '', 
                            postal_code = '', 
                            street_address = '', ), 
                        card_type = '', 
                        cardholder_name = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by_user = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        default = True, 
                        email = '', 
                        expiration_month = '', 
                        expiration_year = '', 
                        href = '', 
                        id = '', 
                        name = '', 
                        organization = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        projects = [
                            
                            ], 
                        type = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaymentMethodList(
        )
        """

    def testPaymentMethodList(self):
        """Test PaymentMethodList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.invoice import Invoice

class TestInvoice(unittest.TestCase):
    """Invoice unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Invoice:
        """Test Invoice
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Invoice`
        """
        model = Invoice()
        if include_optional:
            return Invoice(
                amount = 1.337,
                balance = 1.337,
                created_on = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                credit_amount = 1.337,
                credits_applied = 1.337,
                currency = 'USD',
                due_on = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                href = '',
                id = '',
                items = [
                    equinix.services.metalv1.models.line_item.LineItem(
                        adjustments = [
                            equinix.services.metalv1.models.line_item_adjustment.LineItemAdjustment(
                                amount = 1.337, 
                                description = '', 
                                href = '', )
                            ], 
                        amount = 1.337, 
                        currency = '', 
                        description = '', 
                        details = '', 
                        end_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        hostname = '', 
                        href = '', 
                        item_type = '', 
                        location = '', 
                        plan = equinix.services.metalv1.models.plan_id_name.PlanIdName(
                            href = '', 
                            id = '', 
                            name = '', ), 
                        plan_id = '', 
                        project = equinix.services.metalv1.models.project_id_name.ProjectIdName(
                            href = '', 
                            id = '', 
                            name = '', ), 
                        project_id = '', 
                        service_id = '', 
                        start_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        unit = '', 
                        unit_price = 1.337, )
                    ],
                number = '',
                project = equinix.services.metalv1.models.project_id_name.ProjectIdName(
                    href = '', 
                    id = '', 
                    name = '', ),
                reference_number = '',
                status = '',
                target_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date()
            )
        else:
            return Invoice(
        )
        """

    def testInvoice(self):
        """Test Invoice"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.fabricv4.models.pagination import Pagination
from equinix.services.fabricv4.models.price import Price
from typing import Optional, Set
from typing_extensions import Self

class PriceSearchResponse(BaseModel):
    """
    PriceSearchResponse
    """ # noqa: E501
    data: Optional[List[Price]] = None
    pagination: Optional[Pagination] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["data", "pagination"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PriceSearchResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item in self.data:
                if _item:
                    _items.append(_item.to_dict())
            _dict['data'] = _items
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict['pagination'] = self.pagination.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PriceSearchResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data": [Price.from_dict(_item) for _item in obj["data"]] if obj.get("data") is not None else None,
            "pagination": Pagination.from_dict(obj["pagination"]) if obj.get("pagination") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.organization_input import OrganizationInput

class TestOrganizationInput(unittest.TestCase):
    """OrganizationInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationInput:
        """Test OrganizationInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationInput`
        """
        model = OrganizationInput()
        if include_optional:
            return OrganizationInput(
                address = equinix.services.metalv1.models.address.Address(
                    address = '', 
                    address2 = '', 
                    city = '', 
                    coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                        href = '', 
                        latitude = '', 
                        longitude = '', ), 
                    country = '', 
                    href = '', 
                    state = '', 
                    zip_code = '', ),
                billing_address = equinix.services.metalv1.models.address.Address(
                    address = '', 
                    address2 = '', 
                    city = '', 
                    coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                        href = '', 
                        latitude = '', 
                        longitude = '', ), 
                    country = '', 
                    href = '', 
                    state = '', 
                    zip_code = '', ),
                customdata = None,
                description = '',
                enforce_2fa_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                href = '',
                name = '',
                twitter = '',
                website = ''
            )
        else:
            return OrganizationInput(
        )
        """

    def testOrganizationInput(self):
        """Test OrganizationInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.ip_address import IPAddress

class TestIPAddress(unittest.TestCase):
    """IPAddress unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IPAddress:
        """Test IPAddress
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IPAddress`
        """
        model = IPAddress()
        if include_optional:
            return IPAddress(
                address_family = 4,
                cidr = 28,
                href = '',
                ip_reservations = [
                    ''
                    ],
                public = False
            )
        else:
            return IPAddress(
        )
        """

    def testIPAddress(self):
        """Test IPAddress"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.hardware_reservation import HardwareReservation

class TestHardwareReservation(unittest.TestCase):
    """HardwareReservation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HardwareReservation:
        """Test HardwareReservation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HardwareReservation`
        """
        model = HardwareReservation()
        if include_optional:
            return HardwareReservation(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                custom_rate = 1050.5,
                device = equinix.services.metalv1.models.device.Device(
                    actions = [
                        equinix.services.metalv1.models.device_actions_inner.Device_actions_inner(
                            href = '', 
                            name = '', 
                            type = '', )
                        ], 
                    always_pxe = True, 
                    billing_cycle = '', 
                    bonding_mode = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_by = null, 
                    customdata = { }, 
                    description = '', 
                    facility = equinix.services.metalv1.models.facility.Facility(
                        address = equinix.services.metalv1.models.address.Address(
                            address2 = '', 
                            city = '', 
                            coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                                href = '', 
                                latitude = '', 
                                longitude = '', ), 
                            country = '', 
                            href = '', 
                            state = '', 
                            zip_code = '', ), 
                        code = '', 
                        features = ["baremetal","backend_transfer","global_ipv4"], 
                        href = '', 
                        id = '', 
                        ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                        metro = null, 
                        name = '', ), 
                    firmware_set_id = '', 
                    hardware_reservation = equinix.services.metalv1.models.hardware_reservation.HardwareReservation(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        custom_rate = 1050.5, 
                        href = '', 
                        id = '', 
                        need_of_service = True, 
                        plan = equinix.services.metalv1.models.plan.Plan(
                            available_in = [
                                equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                    href = '', 
                                    price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                        hour = 1.23, 
                                        href = '', ), )
                                ], 
                            available_in_metros = [
                                equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                    href = '', )
                                ], 
                            categories = [
                                ''
                                ], 
                            class = 'm3.large.x86', 
                            deployment_types = [
                                'on_demand'
                                ], 
                            description = '', 
                            href = '', 
                            id = '', 
                            legacy = True, 
                            line = '', 
                            name = '', 
                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                            slug = 'm3.large.x86', 
                            specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                                cpus = [
                                    equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                        count = 56, 
                                        href = '', 
                                        type = '', )
                                    ], 
                                drives = [
                                    equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                        category = '', 
                                        count = 56, 
                                        href = '', 
                                        size = '3.84TB', 
                                        type = '', )
                                    ], 
                                features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                    href = '', 
                                    raid = True, 
                                    txt = True, 
                                    uefi = True, ), 
                                href = '', 
                                memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                    href = '', 
                                    total = '', ), 
                                nics = [
                                    equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                        count = 2, 
                                        href = '', 
                                        type = '', )
                                    ], ), 
                            type = 'standard', ), 
                        project = equinix.services.metalv1.models.project.Project(
                            backend_transfer_enabled = True, 
                            bgp_config = equinix.services.metalv1.models.href.Href(
                                href = '', ), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            devices = [
                                equinix.services.metalv1.models.href.Href(
                                    href = '', )
                                ], 
                            href = '', 
                            id = '', 
                            invitations = [
                                
                                ], 
                            max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                            members = [
                                
                                ], 
                            memberships = [
                                
                                ], 
                            name = '0', 
                            network_status = equinix.services.metalv1.models.network_status.network_status(), 
                            organization = , 
                            payment_method = , 
                            ssh_keys = [
                                
                                ], 
                            tags = [
                                ''
                                ], 
                            type = 'default', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', 
                            volumes = [
                                
                                ], ), 
                        provisionable = True, 
                        short_id = '', 
                        spare = True, 
                        switch_uuid = '', 
                        termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    hostname = '', 
                    href = '', 
                    id = '', 
                    image_url = '', 
                    ip_addresses = [
                        equinix.services.metalv1.models.ip_assignment.IPAssignment(
                            address_family = 56, 
                            assigned_to = , 
                            cidr = 56, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            enabled = True, 
                            gateway = '', 
                            global_ip = True, 
                            href = '', 
                            id = '', 
                            manageable = True, 
                            management = True, 
                            netmask = '', 
                            network = '', 
                            next_hop = '', 
                            parent_block = equinix.services.metalv1.models.parent_block.ParentBlock(
                                cidr = 56, 
                                href = '', 
                                netmask = '', 
                                network = '', ), 
                            public = True, 
                            state = 'pending', )
                        ], 
                    ipxe_script_url = '', 
                    iqn = '', 
                    locked = True, 
                    metro = null, 
                    network_frozen = True, 
                    network_ports = [
                        equinix.services.metalv1.models.port.Port(
                            bond = equinix.services.metalv1.models.bond_port_data.BondPortData(
                                href = '', 
                                id = '', 
                                name = '', ), 
                            data = equinix.services.metalv1.models.port_data.PortData(
                                bonded = True, 
                                href = '', 
                                mac = '', ), 
                            disbond_operation_supported = True, 
                            href = '', 
                            id = '', 
                            name = 'bond0', 
                            native_virtual_network = equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                assigned_to_virtual_circuit = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                description = '', 
                                href = '', 
                                id = '', 
                                instances = [
                                    equinix.services.metalv1.models.device.Device(
                                        always_pxe = True, 
                                        billing_cycle = '', 
                                        bonding_mode = 56, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        description = '', 
                                        firmware_set_id = '', 
                                        hostname = '', 
                                        href = '', 
                                        id = '', 
                                        image_url = '', 
                                        ipxe_script_url = '', 
                                        iqn = '', 
                                        locked = True, 
                                        network_frozen = True, 
                                        operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                                            build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                            default_operating_system = True, 
                                            deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                            distro = '', 
                                            distro_label = '', 
                                            end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                            end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                            href = '', 
                                            id = '', 
                                            licensed = True, 
                                            lifecycle_state = '', 
                                            name = '', 
                                            preinstallable = True, 
                                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                            provisionable_on = [
                                                ''
                                                ], 
                                            release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                            release_notes = '', 
                                            slug = '', 
                                            version = '', ), 
                                        project_lite = null, 
                                        provisioning_events = [
                                            equinix.services.metalv1.models.event.Event(
                                                body = '', 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                href = '', 
                                                id = '', 
                                                interpolated = '', 
                                                ip = '', 
                                                modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                                relationships = [
                                                    
                                                    ], 
                                                state = '', 
                                                type = '', )
                                            ], 
                                        provisioning_percentage = 1.337, 
                                        root_password = '', 
                                        short_id = '', 
                                        sos = '', 
                                        spot_instance = True, 
                                        spot_price_max = 1.337, 
                                        state = 'queued', 
                                        storage = equinix.services.metalv1.models.storage.Storage(
                                            disks = [
                                                equinix.services.metalv1.models.disk.Disk(
                                                    href = '', 
                                                    partitions = [
                                                        equinix.services.metalv1.models.partition.Partition(
                                                            href = '', 
                                                            label = '', 
                                                            number = 56, 
                                                            size = '', )
                                                        ], 
                                                    wipe_table = True, )
                                                ], 
                                            filesystems = [
                                                equinix.services.metalv1.models.filesystem.Filesystem(
                                                    href = '', 
                                                    mount = equinix.services.metalv1.models.mount.Mount(
                                                        format = '', 
                                                        href = '', 
                                                        options = [
                                                            ''
                                                            ], 
                                                        point = '', ), )
                                                ], 
                                            href = '', 
                                            raid = [
                                                equinix.services.metalv1.models.raid.Raid(
                                                    href = '', 
                                                    level = '', 
                                                    name = '', )
                                                ], ), 
                                        switch_uuid = '', 
                                        termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        user = '', 
                                        userdata = '', )
                                    ], 
                                metal_gateways = [
                                    equinix.services.metalv1.models.metal_gateway_lite.MetalGatewayLite(
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        gateway_address = '10.1.2.1/27', 
                                        href = '', 
                                        id = '', 
                                        state = 'ready', 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        vlan = 1001, )
                                    ], 
                                metro_code = '', 
                                vxlan = 56, ), 
                            network_type = 'layer2-bonded', 
                            type = 'NetworkPort', 
                            virtual_networks = [
                                equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                    assigned_to_virtual_circuit = True, 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    description = '', 
                                    href = '', 
                                    id = '', 
                                    metro_code = '', 
                                    vxlan = 56, )
                                ], )
                        ], 
                    operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                        build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        default_operating_system = True, 
                        deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        distro = '', 
                        distro_label = '', 
                        end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        href = '', 
                        id = '', 
                        licensed = True, 
                        lifecycle_state = '', 
                        name = '', 
                        preinstallable = True, 
                        pricing = equinix.services.metalv1.models.pricing.pricing(), 
                        release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        release_notes = '', 
                        slug = '', 
                        version = '', ), 
                    plan = equinix.services.metalv1.models.plan.Plan(
                        class = 'm3.large.x86', 
                        description = '', 
                        href = '', 
                        id = '', 
                        legacy = True, 
                        line = '', 
                        name = '', 
                        pricing = equinix.services.metalv1.models.pricing.pricing(), 
                        slug = 'm3.large.x86', 
                        type = 'standard', ), 
                    project = equinix.services.metalv1.models.project.Project(
                        backend_transfer_enabled = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        href = '', 
                        id = '', 
                        max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                        name = '0', 
                        network_status = equinix.services.metalv1.models.network_status.network_status(), 
                        type = 'default', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', ), 
                    project_lite = null, 
                    provisioning_events = [
                        equinix.services.metalv1.models.event.Event(
                            body = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            href = '', 
                            id = '', 
                            interpolated = '', 
                            ip = '', 
                            modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                            state = '', 
                            type = '', )
                        ], 
                    provisioning_percentage = 1.337, 
                    root_password = '', 
                    short_id = '', 
                    sos = '', 
                    spot_instance = True, 
                    spot_price_max = 1.337, 
                    ssh_keys = [
                        
                        ], 
                    state = 'queued', 
                    storage = equinix.services.metalv1.models.storage.Storage(
                        href = '', ), 
                    switch_uuid = '', 
                    tags = [
                        ''
                        ], 
                    termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user = '', 
                    userdata = '', 
                    volumes = [
                        
                        ], ),
                facility = equinix.services.metalv1.models.facility.Facility(
                    address = equinix.services.metalv1.models.address.Address(
                        address2 = '', 
                        city = '', 
                        coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                            href = '', 
                            latitude = '', 
                            longitude = '', ), 
                        country = '', 
                        href = '', 
                        state = '', 
                        zip_code = '', ), 
                    code = '', 
                    features = ["baremetal","backend_transfer","global_ipv4"], 
                    href = '', 
                    id = '', 
                    ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                    metro = null, 
                    name = '', ),
                href = '',
                id = '',
                need_of_service = True,
                plan = equinix.services.metalv1.models.plan.Plan(
                    available_in = [
                        equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                            href = '', 
                            price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                hour = 1.23, 
                                href = '', ), )
                        ], 
                    available_in_metros = [
                        equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                            href = '', )
                        ], 
                    categories = [
                        ''
                        ], 
                    class = 'm3.large.x86', 
                    deployment_types = [
                        'on_demand'
                        ], 
                    description = '', 
                    href = '', 
                    id = '', 
                    legacy = True, 
                    line = '', 
                    name = '', 
                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                    slug = 'm3.large.x86', 
                    specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                        cpus = [
                            equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                count = 56, 
                                href = '', 
                                type = '', )
                            ], 
                        drives = [
                            equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                category = '', 
                                count = 56, 
                                href = '', 
                                size = '3.84TB', 
                                type = '', )
                            ], 
                        features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                            href = '', 
                            raid = True, 
                            txt = True, 
                            uefi = True, ), 
                        href = '', 
                        memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                            href = '', 
                            total = '', ), 
                        nics = [
                            equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                count = 2, 
                                href = '', 
                                type = '', )
                            ], ), 
                    type = 'standard', ),
                project = equinix.services.metalv1.models.project.Project(
                    backend_transfer_enabled = True, 
                    bgp_config = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    devices = [
                        equinix.services.metalv1.models.href.Href(
                            href = '', )
                        ], 
                    href = '', 
                    id = '', 
                    invitations = [
                        
                        ], 
                    max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                    members = [
                        
                        ], 
                    memberships = [
                        
                        ], 
                    name = '0', 
                    network_status = equinix.services.metalv1.models.network_status.network_status(), 
                    organization = , 
                    payment_method = , 
                    ssh_keys = [
                        
                        ], 
                    tags = [
                        ''
                        ], 
                    type = 'default', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    volumes = [
                        
                        ], ),
                provisionable = True,
                short_id = '',
                spare = True,
                switch_uuid = '',
                termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return HardwareReservation(
        )
        """

    def testHardwareReservation(self):
        """Test HardwareReservation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.href import Href
from typing import Optional, Set
from typing_extensions import Self

class AuthTokenUser(BaseModel):
    """
    AuthTokenUser
    """ # noqa: E501
    avatar_thumb_url: Optional[StrictStr] = None
    avatar_url: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    customdata: Optional[Dict[str, Any]] = None
    default_organization_id: Optional[StrictStr] = None
    default_project_id: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    emails: Optional[List[Href]] = None
    first_name: Optional[StrictStr] = None
    fraud_score: Optional[StrictStr] = None
    full_name: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    last_login_at: Optional[datetime] = None
    last_name: Optional[StrictStr] = None
    max_organizations: Optional[StrictInt] = None
    max_projects: Optional[StrictInt] = None
    phone_number: Optional[StrictStr] = None
    short_id: Optional[StrictStr] = None
    timezone: Optional[StrictStr] = None
    two_factor_auth: Optional[StrictStr] = None
    updated_at: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["avatar_thumb_url", "avatar_url", "created_at", "customdata", "default_organization_id", "default_project_id", "email", "emails", "first_name", "fraud_score", "full_name", "href", "id", "last_login_at", "last_name", "max_organizations", "max_projects", "phone_number", "short_id", "timezone", "two_factor_auth", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuthTokenUser from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in emails (list)
        _items = []
        if self.emails:
            for _item in self.emails:
                if _item:
                    _items.append(_item.to_dict())
            _dict['emails'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuthTokenUser from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "avatar_thumb_url": obj.get("avatar_thumb_url"),
            "avatar_url": obj.get("avatar_url"),
            "created_at": obj.get("created_at"),
            "customdata": obj.get("customdata"),
            "default_organization_id": obj.get("default_organization_id"),
            "default_project_id": obj.get("default_project_id"),
            "email": obj.get("email"),
            "emails": [Href.from_dict(_item) for _item in obj["emails"]] if obj.get("emails") is not None else None,
            "first_name": obj.get("first_name"),
            "fraud_score": obj.get("fraud_score"),
            "full_name": obj.get("full_name"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "last_login_at": obj.get("last_login_at"),
            "last_name": obj.get("last_name"),
            "max_organizations": obj.get("max_organizations"),
            "max_projects": obj.get("max_projects"),
            "phone_number": obj.get("phone_number"),
            "short_id": obj.get("short_id"),
            "timezone": obj.get("timezone"),
            "two_factor_auth": obj.get("two_factor_auth"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_market_request_create_input import SpotMarketRequestCreateInput

class TestSpotMarketRequestCreateInput(unittest.TestCase):
    """SpotMarketRequestCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotMarketRequestCreateInput:
        """Test SpotMarketRequestCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotMarketRequestCreateInput`
        """
        model = SpotMarketRequestCreateInput()
        if include_optional:
            return SpotMarketRequestCreateInput(
                devices_max = 56,
                devices_min = 56,
                end_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                facilities = [
                    ''
                    ],
                href = '',
                instance_parameters = equinix.services.metalv1.models.spot_market_request_create_input_instance_parameters.SpotMarketRequestCreateInput_instance_parameters(
                    always_pxe = True, 
                    billing_cycle = '', 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    description = '', 
                    features = [
                        ''
                        ], 
                    hostname = '', 
                    hostnames = [
                        ''
                        ], 
                    href = '', 
                    locked = True, 
                    no_ssh_keys = True, 
                    operating_system = '', 
                    plan = '', 
                    private_ipv4_subnet_size = 56, 
                    project_ssh_keys = [
                        ''
                        ], 
                    public_ipv4_subnet_size = 56, 
                    tags = [
                        ''
                        ], 
                    termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user_ssh_keys = [
                        ''
                        ], 
                    userdata = '', ),
                max_bid_price = 1.337,
                metro = ''
            )
        else:
            return SpotMarketRequestCreateInput(
        )
        """

    def testSpotMarketRequestCreateInput(self):
        """Test SpotMarketRequestCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
